@@ -32,6 +32,9 @@ class PowerMeasurement:
     def __float__(self) -> float:
         return float(self.dynamic + self.static)
 
+    def __int__(self) -> float:
+        return int(self.dynamic + self.static)
+
     def __add__(self, other):
         return PowerMeasurement(self.dynamic + other.dynamic, self.static + other.static)
 
@@ -53,6 +56,7 @@ class PowerMeasurement:
 
 class PowerModel(ABC):
     """Abstract base class for power models."""
+
     # TODO: Validator! Only one power model per entity
 
     @abstractmethod
@@ -68,7 +72,7 @@ class PowerModel(ABC):
 
 
 class PowerModelNode(PowerModel):
-    def __init__(self, max_power: float, static_power: float):
+    def __init__(self, max_power: float = None, power_per_cu: float = None, static_power: float = 0):
         """Power model for compute nodes with static and dynamic power usage.
 
         Power usage is scaled linearly with resource usage.
@@ -78,43 +82,32 @@ class PowerModelNode(PowerModel):
             up to 150 Watt when under full load (`max_power=150`).
 
         Args:
-            max_power: Maximum power usage of the node under full load.
+            max_power: Maximum power usage of the node under full load. Cannot be combined with `power_per_cu`.
+            power_per_cu: Incremental power usage for each used compute unit. Cannot be combined with `max_power`.
             static_power: Idle power usage of the node without any load.
         """
+        if max_power is None and power_per_cu is None:
+            raise ValueError("Either `max_power` or `power_per_cu` have to be stated.")
+        if max_power is not None and power_per_cu is not None:
+            raise ValueError("The parameters `max_power` or `power_per_cu` cannot be combined.")
         self.max_power = max_power
+        self.power_per_cu = power_per_cu
         self.static_power = static_power
         self.node = None
 
     def measure(self) -> PowerMeasurement:
-        dynamic_power = (self.max_power - self.static_power) * self.node.utilization()
+        if self.max_power is not None:
+            dynamic_power = (self.max_power - self.static_power) * self.node.utilization()
+        elif self.power_per_cu is not None:
+            dynamic_power = self.power_per_cu * self.node.used_cu
+        else:
+            raise RuntimeError("Invalid state of PowerModelNode: `max_power` and `power_per_cu` are undefined.")
         return PowerMeasurement(dynamic=dynamic_power, static=self.static_power)
 
     def set_parent(self, parent):
         self.node = parent
 
 
-class PowerModelNodeShared(PowerModel):
-    def __init__(self, power_per_mips: float):
-        """Power model for shared infrastructure.
-
-        For nodes such as data centers we may know neither the static nor max power usage and hence define only the
-        incremental power usage.
-
-
-        Args:
-            power_per_mips: Incremental power per million instructions per seconds in W/MIPS (or J/MIP)
-        """
-        self.power_per_mips = power_per_mips
-        self.node = None
-
-    def measure(self) -> PowerMeasurement:
-        dynamic_power = self.power_per_mips * self.node.used_mips
-        return PowerMeasurement(dynamic=dynamic_power, static=0)
-
-    def set_parent(self, parent):
-        self.node = parent
-
-
 class PowerModelLink(PowerModel):
     def __init__(self, energy_per_bit: float):
         """Power model for network links.
@@ -173,60 +166,49 @@ class PowerAware(ABC):
 
 
 class PowerMeter:
-    def __init__(self,
-                 env: simpy.Environment,
-                 entities: Union[PowerAware, Collection[PowerAware], Callable[[], Collection[PowerAware]]],
-                 name: Optional[str] = None,
-                 measurement_interval: Optional[float] = 1,
-                 delay: Optional[float] = 0,
-                 end_time: Optional[float] = math.inf):
-        """PowerMeter with measures and saves the power of one or more entites in regular intervals.
+    """Convenience class that wraps power_meter()."""
+    def __init__(self, env, entities, **kwargs):
+        self.measurements = []
+        env.process(power_meter(env, entities, callback=lambda m: self.measurements.append(m), **kwargs))
 
-        Args:
-            env: Simpy environment (for timing the measurements)
-            entities: Can be either (1) a single :class:`PowerAware` entity (2) a list of :class:`PowerAware` entities
-                (3) a function which returns a list of :class:`PowerAware` entities, if the number of these entities
-                changes during the simulation.
-            name: Name of the power meter for logging and reporting
-            measurement_interval: The measurement interval.
-            delay: The delay after which the measurements shall be conducted. For some scenarios it makes sense to e.g.
-                include a tiny delay to make sure that all events at a previous time step were processed before the
-                measurement is conducted.
-            end_time: No measurements will be conducted after this time
-        """
-        self.env = env
-        self.entities = entities
-        self.measurement_interval = measurement_interval
-        self.delay = delay
-        self.end_time = end_time
-        self.measurements: List[PowerMeasurement] = []
 
-        if name is not None:
-            self.name = name
+def power_meter(env: simpy.Environment,
+                entities: Union[PowerAware, Collection[PowerAware], Callable[[], Collection[PowerAware]]],
+                callback: Callable[[PowerMeasurement], None],
+                name: Optional[str] = None,
+                measurement_interval: Optional[float] = 1,
+                delay: Optional[float] = 0):
+    """Power meter with measures and saves the power of one or more entites in regular intervals.
+
+    Args:
+        env: Simpy environment (for timing the measurements)
+        entities: Can be either (1) a single :class:`PowerAware` entity (2) a list of :class:`PowerAware` entities
+            (3) a function which returns a list of :class:`PowerAware` entities, if the number of these entities
+            changes during the simulation.
+        callback: TODO
+        name: Name of the power meter for logging and reporting
+        measurement_interval: The measurement interval.
+        delay: The delay after which the measurements shall be conducted. For some scenarios it makes sense to e.g.
+            include a tiny delay to make sure that all events at a previous time step were processed before the
+            measurement is conducted.
+    """
+    if name is None:
+        global _unnamed_power_meters_created
+        name = f"power_meter_{_unnamed_power_meters_created}"
+        _unnamed_power_meters_created += 1
+
+    yield env.timeout(delay)
+    while True:
+        if isinstance(entities, PowerAware):
+            measurement = entities.measure_power()
         else:
-            global _unnamed_power_meters_created
-            self.name = f"power_meter_{_unnamed_power_meters_created}"
-            _unnamed_power_meters_created += 1
-
-        self.process = env.process(self._run())
-
-    def _run(self):
-        yield self.env.timeout(self.delay)
-        while self.env.now < self.end_time:
-            if isinstance(self.entities, PowerAware):
-                measurement = self.entities.measure_power()
+            if isinstance(entities, Collection):
+                entities = entities
+            elif isinstance(entities, Callable):
+                entities = entities()
             else:
-                if isinstance(self.entities, Collection):
-                    entities = self.entities
-                elif isinstance(self.entities, Callable):
-                    entities = self.entities()
-                else:
-                    raise ValueError(f"{self.name}: Unsupported type {type(self.entities)} for observable={self.entities}.")
-                measurement = PowerMeasurement.sum(entity.measure_power() for entity in entities)
-            self.measurements.append(measurement)
-            logger.debug(f"{self.env.now}: {self.name}: {measurement}")
-            yield self.env.timeout(self.measurement_interval)
-
-    def stop(self):
-        """Stop the power meter from conducting further measurements."""
-        self.end_time = self.env.now
+                raise ValueError(f"{name}: Unsupported type {type(entities)} for observable={entities}.")
+            measurement = PowerMeasurement.sum(entity.measure_power() for entity in entities)
+        callback(measurement)
+        logger.debug(f"{env.now}: {name}: {measurement}")
+        yield env.timeout(measurement_interval)
